@@ -25,15 +25,17 @@
 #ifndef PARTMAN_H
 #define PARTMAN_H
 
+#include <QCommandLineParser>
 #include <QAbstractItemModel>
 #include <QStyledItemDelegate>
 #include <QString>
 #include <QMap>
 #include <QStack>
 
-#include "mprocess.h"
 #include "ui_meinstall.h"
+#include "mprocess.h"
 #include "msettings.h"
+#include "safecache.h"
 
 class DeviceItem
 {
@@ -50,6 +52,7 @@ class DeviceItem
     void labelParts();
 public:
     DeviceItem *active = nullptr;
+    DeviceItem *origin = nullptr;
     enum DeviceType {
         Unknown,
         Drive,
@@ -59,6 +62,7 @@ public:
         Subvolume
     } type;
     struct Flags {
+        bool rotational : 1;
         bool nasty : 1;
         bool curEmpty : 1;
         bool oldLayout : 1;
@@ -68,7 +72,7 @@ public:
         bool curESP : 1;
         bool volCrypto : 1;
     } flags = {};
-    QString model, device, devMapper;
+    QString model, device, path, devMapper;
     QString label, curLabel;
     QString usefor;
     QString format, curFormat;
@@ -77,6 +81,7 @@ public:
     int mapCount = 0;
     int physec;
     int pass = 0;
+    int discgran = 0;
     bool encrypt = false;
     bool chkbadblk = false;
     bool dump = false;
@@ -101,7 +106,8 @@ public:
     bool willUseGPT() const;
     bool willFormat() const;
     bool canEncrypt() const;
-    QString mappedDevice(const bool full = false) const;
+    bool willEncrypt() const;
+    QString mappedDevice() const;
     bool willMap() const;
     QString shownDevice() const;
     QStringList allowedUsesFor(bool real = true) const;
@@ -151,13 +157,13 @@ class PartMan : public QAbstractItemModel
     DeviceItem *changing = nullptr;
     Ui::MeInstall &gui;
     QWidget *master;
-    QMap<QString, DeviceItem *> mounts;
-    void setup();
+    SafeCache key;
+    QMap<QString, QString> defaultLabels;
+    bool brave, gptoverride;
     void scanVirtualDevices(bool rescan);
     void resizeColumnsToFit();
     bool formatLinuxPartition(const QString &devpath, const QString &format, bool chkBadBlocks, const QString &label);
     bool prepareSubvolumes(DeviceItem *partit);
-    DeviceItem *findOrigin(const QString &vdev);
     void treeItemChange();
     void treeSelChange();
     void treeMenu(const QPoint &);
@@ -165,12 +171,13 @@ class PartMan : public QAbstractItemModel
     void partClearClick(bool);
     void partAddClick(bool);
     void partRemoveClick(bool);
+    void partReloadClick();
+    void partManRunClick();
     void partMenuUnlock(DeviceItem *twit);
     void partMenuLock(DeviceItem *twit);
     void scanSubvolumes(DeviceItem *partit);
-    bool luksFormat(const QString &dev, const QByteArray &password);
-    bool luksOpen(const QString &dev, const QString &luksfs,
-        const QByteArray &password, const QString &options = QString());
+    bool luksFormat(DeviceItem *partit, const QByteArray &password);
+    bool luksOpen(DeviceItem *partit, const QString &luksfs, const QByteArray &password);
 public:
     enum TreeColumns {
         Device,
@@ -186,11 +193,10 @@ public:
         _TreeColumns_
     };
     QString bootUUID;
-    bool gptoverride=false, uefi=false, brave=false;
     long long rootSpaceNeeded = 0;
     long long bootSpaceNeeded = 0;
-    QMap<QString, QString> defaultLabels;
-    PartMan(MProcess &mproc, Ui::MeInstall &ui, QWidget *parent);
+    QMap<QString, DeviceItem *> mounts;
+    PartMan(MProcess &mproc, Ui::MeInstall &ui, const QSettings &appConf, const QCommandLineParser &appArgs);
     void scan(DeviceItem *drvstart = nullptr);
     bool manageConfig(MSettings &config, bool save);
     bool composeValidate(bool automatic, const QString &project);
@@ -200,7 +206,8 @@ public:
     int countPrepSteps();
     bool preparePartitions();
     bool formatPartitions();
-    bool fixCryptoSetup(const QString &keyfile, bool isNewKey);
+    void loadKeyMaterial(const QString &keyfile);
+    bool fixCryptoSetup();
     bool makeFstab(bool populateMediaMounts);
     bool mountPartitions();
     void unmount();
@@ -208,7 +215,7 @@ public:
     QString getMountDev(const QString &point, const bool mapped=true);
     int swapCount();
     int isEncrypt(const QString &point);
-    DeviceItem *findDevice(const QString &devname) const;
+    DeviceItem *findByPath(const QString &devpath) const;
     // Model View Controller
     QVariant data(const QModelIndex &index, int role) const override;
     bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
